import React, {useState} from 'react'
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import FormInput from "../FormInput.js"
import {CompletarCadastroButton} from './TabPanelSolicitarContaProfessor.js'
import {ButtonCancelar} from './TabPanelEditarPerfil.js'

function validateUserInput(type, input, confirmation) {
    let flag = false

    if (type === 'senha') {
        if(input.length < 8) {
            flag = true
        }
    }
    else if (type === 'confirmacao') {
        if (input !== confirmation)
            flag = true
    }

    return flag
}

function validateUserEmail(input) {
    let flag = false

    if(input.split("").filter(x => x === "@").length !== 1 || !(input.match(/^([\w.%+-]+)@([\w-]+\.)+([\w]{2,})$/i))) {
        flag = true
    }
    return flag
}

export default function TabPanelGerenciarConta (props) {
    const [senhaAtual, setSenhaAtual] = useState(
        {
            dict : {
                key : false,
                value : localStorage.getItem("@portalmec/senha") || ""
            }
        }
    )

    const [novaSenha, setNovaSenha] = useState(
        {
            dict : {
                key : false,
                value : ""
            }
        }
    )

    const [novaSenhaConfirmacao, setNovaSenhaConfirmacao] = useState(
        {
            dict : {
                key : false,
                value : ""
            }
        }
    )

    const [novoEmail, setNovoEmail] = useState(
        {
            dict : {
                key : false,
                value : ""
            }
        }
    )

    const handleChangeSenha = (e, type) => {
        const userInput = e.target.value
        const flag = (type === 'confirmacao' ? validateUserInput('confirmacao', userInput, novaSenha.dict.value) : validateUserInput('senha', userInput, ''))

        if(type === 'senhaAtual') {
            setSenhaAtual({...senhaAtual, dict : {
                key : flag,
                value : userInput
            }})
            console.log(senhaAtual)
        }
        else if(type === 'novaSenha') {
            setNovaSenha({...novaSenha, dict : {
                key : flag,
                value : userInput
            }})
            console.log(novaSenha)
        }
        else if (type === 'confirmacao'){
            setNovaSenhaConfirmacao({...novaSenhaConfirmacao, dict : {
                key : flag,
                value : userInput
            }})
            console.log(novaSenhaConfirmacao)
        }
    }

    const handleChangeEmail = (e) => {
        const userInput = e.target.value
        const flag = validateUserEmail(userInput)

        setNovoEmail({...novoEmail, dict : {
            key : flag,
            value : userInput
        }})

        console.log(novoEmail)
    }

    const limpaCamposForm = () => {
        setSenhaAtual({...senhaAtual, dict : {
            key : false,
            value : ''
        }})

        setNovaSenha({...novaSenha, dict : {
            key : false,
            value : ''
        }})

        setNovaSenhaConfirmacao({...novaSenhaConfirmacao, dict : {
            key : false,
            value : ''
        }})
    }

    const onSubmit = (e, type) => {
        e.preventDefault()

        if (type === 'senha'){
            if (senhaAtual.dict.value === localStorage.getItem("@portalmec/senha")) {
                const login = {senhaAtual : senhaAtual.dict.value, novaSenha : novaSenha.dict.value, novaSenhaConfirmacao : novaSenhaConfirmacao.dict.value}

                if (!(senhaAtual.dict.key || novaSenha.dict.key || novaSenhaConfirmacao.dict.key)) {
                    console.log(login)
                    limpaCamposForm()
                    props.handleSnackbar()
                }
            }
            else {
                console.log(localStorage.getItem("@portalmec/senha"), senhaAtual.dict.value)
            }
        }
        else {
            console.log(novoEmail.dict.value)
        }

    }

    return (
        <>
        <Paper elevation={3} style= {{width:"100%"}}>
        <div className='card-config'>
            <div className='content-div'>
                <h1>Gerenciar Conta</h1>
                <div style={{display : "flex", flexDirection : "column"}}>
                    <form style={{width:"500px", margin : "0 0 20px 0"}} onSubmit={e => onSubmit(e, 'senha')}>
                        <h4 style={{display:"flex", justifyContent:"flex-start", fontSize:"18px"}}>Alterar Senha</h4>
                        <FormInput
                            inputType={"password"}
                            name={"Senha Atual"}
                            value={senhaAtual.dict.value}
                            placeholder={"Senha atual"}
                            handleChange={e => handleChangeSenha(e, 'senhaAtual')}
                            required={true}
                            error={senhaAtual.dict.key}
                            help={ senhaAtual.dict.key ? "Faltou inserir sua senha atual" : ""}
                        />
                        <FormInput
                            inputType={"password"}
                            name={"Nova senha"}
                            value={novaSenha.dict.value}
                            placeholder={"Nova senha"}
                            handleChange={e => handleChangeSenha(e, 'novaSenha')}
                            required={true}
                            error={novaSenha.dict.key}
                            help={ novaSenha.dict.key ? (novaSenha.dict.value.length == 0 ? "Faltou definir uma nova senha" : "A senha precisa ter no mínimo 8 caracteres.") : ""}
                        />
                        <FormInput
                            inputType={"password"}
                            name={"Digite novamente a nova senha"}
                            value={novaSenhaConfirmacao.dict.value}
                            placeholder={"Digite novamente a nova senha"}
                            handleChange={e => handleChangeSenha(e, 'confirmacao')}
                            required={true}
                            error={novaSenhaConfirmacao.dict.key}
                            help={ novaSenhaConfirmacao.dict.key ? "As senhas devem ser iguais" : ""}
                        />
                        <div style={{display:"flex", flexDirection:"row", justifyContent:"space-evenly"}}>
                            <span style={{paddingTop:"0.7em"}}><a href="recuperar-senha" style={{textAlign: "flex-start", color:"#00bcd4"}}>Esqueceu a senha?</a></span>
                            <div style={{margin:"0"}}>
                                <ButtonCancelar onClick={limpaCamposForm}>Limpar Campos</ButtonCancelar>
                                <CompletarCadastroButton type="submit">Alterar Senha</CompletarCadastroButton>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
        </Paper>
        <Paper elevation={3}  style= {{width:"100%"}}>
        <div className='card-config'>
            <div className='content-div'>
                <div style={{display : "flex", flexDirection : "column"}}>
                    <form style={{width:"500px"}} onSubmit={(e) => onSubmit(e, 'email')}>
                        <h4 style={{display:"flex", justifyContent:"flex-start", fontSize:"18px"}}>Alterar e-mail</h4>
                        <FormInput
                            inputType={"text"}
                            name={"email"}
                            value={novoEmail.dict.value}
                            placeholder={"E-mail"}
                            handleChange={e => handleChangeEmail(e)}
                            required={true}
                            error = {novoEmail.dict.key}
                        />
                        <div style={{margin:"0", display:"flex", justifyContent:"flex-start"}}>
                            <CompletarCadastroButton type="submit">SALVAR ALTERAÇÕES</CompletarCadastroButton>
                        </div>
                    </form>
                </div>
            </div>
        </div>
        </Paper>
        <Paper elevation={3}  style= {{width:"100%"}}>
        <div className='card-config'>
            <div className='content-div'>
                <div>
                    <h4 style={{display:"flex", justifyContent:"flex-start", fontSize:"18px"}}>Conta</h4>
                    <span style={{margin:"0", display:"flex", justifyContent:"flex-start"}}>Antes de excluir a sua conta, saiba que ela será removida permanentemente.</span>
                </div>
                <div style={{margin:"0", display:"flex", justifyContent:"flex-start"}}>
                    <ButtonCancelar style={{color:'#eb4034'}}>EXCLUIR CONTA</ButtonCancelar>
                </div>
            </div>
        </div>
        </Paper>
        </>
    )
}
